<?php
/**
 * @package WordPress
 * @subpackage Toolbox
 */

/**
 * Make theme available for translation
 * Translations can be filed in the /languages/ directory
 * If you're building a theme based on toolbox, use a find and replace
 * to change 'toolbox' to the name of your theme in all the template files
 */
load_theme_textdomain( 'toolbox', TEMPLATEPATH . '/languages' );

$locale = get_locale();
$locale_file = TEMPLATEPATH . "/languages/$locale.php";
if ( is_readable( $locale_file ) )
	require_once( $locale_file );

/**
 * Set the content width based on the theme's design and stylesheet.
 */
if ( ! isset( $content_width ) )
	$content_width = 640; /* pixels */

/**
 * This theme uses wp_nav_menu() in one location.
 */
register_nav_menus( array(
	'primary' => __( 'Primary Menu', 'toolbox' ),
) );

/**
 * Add default posts and comments RSS feed links to head
 */
add_theme_support( 'automatic-feed-links' );

/**
 * Add support for the Aside and Gallery Post Formats
 */
add_theme_support( 'post-formats', array( 'aside', 'gallery' ) );

/**
 * Get our wp_nav_menu() fallback, wp_page_menu(), to show a home link.
 */
function toolbox_page_menu_args($args) {
	$args['show_home'] = true;
	return $args;
}
//add_filter( 'wp_page_menu_args', 'toolbox_page_menu_args' );

/**
 * Register widgetized area and update sidebar with default widgets
 */
function toolbox_widgets_init() {
	register_sidebar( array (
		'name' => __( 'Sidebar 1', 'toolbox' ),
		'id' => 'sidebar-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => "</aside>",
		'before_title' => '<h1 class="widget-title">',
		'after_title' => '</h1>',
	) );

	register_sidebar( array (
		'name' => __( 'Sidebar 2', 'toolbox' ),
		'id' => 'sidebar-2',
		'description' => __( 'An optional second sidebar area', 'toolbox' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => "</aside>",
		'before_title' => '<h1 class="widget-title">',
		'after_title' => '</h1>',
	) );	
}
add_action( 'init', 'toolbox_widgets_init' );

/* Theme Options
 * http://themeshaper.com/2010/06/03/sample-theme-options/
*/

require_once ( get_template_directory() . '/theme-options.php' );

/**
 * Custom Header
*/

define('HEADER_TEXTCOLOR', '');
define('HEADER_IMAGE', '%s/images/lego-placeholder.png'); // %s is the template dir uri
define('HEADER_IMAGE_WIDTH', 320);
define('HEADER_IMAGE_HEIGHT', 213);
define('NO_HEADER_TEXT', true );

function admin_header_style() {
	?><style type="text/css">
		#headimg {
			width: <?php echo HEADER_IMAGE_WIDTH; ?>px;
			height: <?php echo HEADER_IMAGE_HEIGHT; ?>px;
		}
	</style><?php
}

function header_style() {
  ?><style type="text/css">
    #team-photo .placeholder {
    	background: #fff url(<?php header_image(); ?>) no-repeat left bottom;
    }
  </style><?php
}

if ( function_exists('add_custom_image_header') ) {
	add_custom_image_header('header_style', 'admin_header_style');
}

/* Twitter Widget
 * Much of this code is borrowed from the Wickett Twitter Widget
 * http://wordpress.org/extend/plugins/wickett-twitter-widget/
*/

if ( !function_exists('wpcom_time_since') ) :
/*
 * Time since function taken from WordPress.com
 */

function wpcom_time_since( $original, $do_more = 0 ) {
        // array of time period chunks
        $chunks = array(
                array(60 * 60 * 24 * 365 , 'year'),
                array(60 * 60 * 24 * 30 , 'month'),
                array(60 * 60 * 24 * 7, 'week'),
                array(60 * 60 * 24 , 'day'),
                array(60 * 60 , 'hour'),
                array(60 , 'minute'),
        );

        $today = time();
        $since = $today - $original;

        for ($i = 0, $j = count($chunks); $i < $j; $i++) {
                $seconds = $chunks[$i][0];
                $name = $chunks[$i][1];

                if (($count = floor($since / $seconds)) != 0)
                        break;
        }

        $print = ($count == 1) ? '1 '.$name : "$count {$name}s";

        if ($i + 1 < $j) {
                $seconds2 = $chunks[$i + 1][0];
                $name2 = $chunks[$i + 1][1];

                // add second item if it's greater than 0
                if ( (($count2 = floor(($since - ($seconds * $count)) / $seconds2)) != 0) && $do_more )
                        $print .= ($count2 == 1) ? ', 1 '.$name2 : ", $count2 {$name2}s";
        }
        return $print;
}
endif;

/**
 * Link a Twitter user mentioned in the tweet text to the user's page on Twitter.
 *
 * @param array $matches regex match
 * @return string Tweet text with inserted @user link
 */
function _wpcom_widget_twitter_username( $matches ) { // $matches has already been through wp_specialchars
	return "$matches[1]<a href='" . esc_url( 'http://twitter.com/' . urlencode( $matches[3] ) ) . "'>@$matches[3]</a>";
}

/**
 * Link a Twitter hashtag with a search results page on Twitter.com
 *
 * @param array $matches regex match
 * @return string Tweet text with inserted #hashtag link
 */
function _wpcom_widget_twitter_hashtag( $matches ) { // $matches has already been through wp_specialchars
	return "$matches[1]<a href='" . esc_url( 'http://twitter.com/search?q=%23' . urlencode( $matches[3] ) ) . "'>#$matches[3]</a>";
}

/**
 * Return a linked up tweet, not wrapped in <li>
 *
 * @param array $tweet is an array taken from the Twitter RSS
 * @return string Linked up tweet string
 */
function get_linked_tweet($tweet) {

	$tweet = array('text' => str_replace('firstlegoleague: ', '', $tweet->get_content()), 'link' => $tweet->get_permalink(), 'created_at' => $tweet->get_date());

	$text = make_clickable( esc_html( $tweet['text'] ) );

	/*
	 * Create links from plain text based on Twitter patterns
	 * @link http://github.com/mzsanford/twitter-text-rb/blob/master/lib/regex.rb Official Twitter regex
	 */
	$text = preg_replace_callback('/(^|[^0-9A-Z&\/]+)(#|\xef\xbc\x83)([0-9A-Z_]*[A-Z_]+[a-z0-9_\xc0-\xd6\xd8-\xf6\xf8\xff]*)/iu', '_wpcom_widget_twitter_hashtag', $text);
	$text = preg_replace_callback('/([^a-zA-Z0-9_]|^)([@\xef\xbc\xa0]+)([a-zA-Z0-9_]{1,20})(\/[a-zA-Z][a-zA-Z0-9\x80-\xff-]{0,79})?/u', '_wpcom_widget_twitter_username', $text);
	return "{$text}\n<a href=\"" . $tweet['link'] . '" class="timesince">' . str_replace(' ', '&nbsp;', wpcom_time_since(strtotime($tweet['created_at']))) . "&nbsp;ago</a>";
}