<?php

add_action( 'admin_init', 'theme_options_init' );
add_action( 'admin_menu', 'theme_options_add_page' );

/**
 * Init plugin options to white list our options
 */
function theme_options_init(){
	register_setting( 'fll_options', 'fll_theme_options', 'theme_options_validate' );
}

/**
 * Load up the menu page
 */
function theme_options_add_page() {
	add_theme_page( __( 'Theme Options' ), __( 'Theme Options' ), 'edit_theme_options', 'theme_options', 'theme_options_do_page' );
}

/**
 * Create the options page
 */
function theme_options_do_page() {
	global $select_options, $radio_options;

	if ( ! isset( $_REQUEST['updated'] ) )
		$_REQUEST['updated'] = false;

	?>
	<div class="wrap">
		<?php screen_icon(); echo "<h2>" . get_current_theme() . __( ' Theme Options' ) . "</h2>"; ?>

		<?php if ( false !== $_REQUEST['updated'] ) : ?>
		<div class="updated fade"><p><strong><?php _e( 'Options saved' ); ?></strong></p></div>
		<?php endif; ?>

		<form method="post" action="options.php">
			<?php settings_fields( 'fll_options' ); ?>
			<?php $options = get_option( 'fll_theme_options' ); ?>

			<table class="form-table">

				<?php
				/**
				 * FLL Options
				 */
				?>
				
				<tr valign="top"><th scope="row"><?php _e( 'FLL Elements' ); ?></th>
					<td>
						
						<input id="fll_theme_options[fll_primary_elements]" name="fll_theme_options[fll_primary_elements]" type="checkbox" value="1" <?php isset($options['fll_primary_elements']) ? checked( '1', $options['fll_primary_elements'] ) : checked('0', '1'); ?> />
						<label class="description" for="fll_theme_options[fll_primary_elements]"><?php _e( 'Enable FLL Theme Elements' ); ?></label><br />
						
						<input id="fll_theme_options[fll_sidebar_twitter]" name="fll_theme_options[fll_sidebar_twitter]" type="checkbox" value="1" <?php isset($options['fll_sidebar_twitter']) ? checked( '1', $options['fll_sidebar_twitter'] ) : checked('1', '1'); ?> />
						<label class="description" for="fll_theme_options[fll_sidebar_twitter]"><?php _e( 'Tweets by @firstlegoleague' ); ?></label><br />
						
						<input id="fll_theme_options[fll_sidebar_youtube]" name="fll_theme_options[fll_sidebar_youtube]" type="checkbox" value="1" <?php isset($options['fll_sidebar_youtube']) ? checked( '1', $options['fll_sidebar_youtube'] ) : checked('1', '1'); ?> />
						<label class="description" for="fll_theme_options[fll_sidebar_youtube]"><?php _e( 'YouTube from FLLGlobal' ); ?></label>
						
					</td>
				</tr>

				<?php
				/**
				 * Header Pin
				 */
				?>
				<tr valign="top"><th scope="row"><?php _e( 'FLL Team Number' ); ?></th>
					<td>
						<input id="fll_theme_options[fll_team_number]" class="regular-text" type="text" name="fll_theme_options[fll_team_number]" value="<?php esc_attr_e( $options['fll_team_number'] ); ?>" />
					</td>
				</tr>
				<tr valign="top"><th scope="row"><?php _e( 'City' ); ?></th>
					<td>
						<input id="fll_theme_options[fll_team_city]" class="regular-text" type="text" name="fll_theme_options[fll_team_city]" value="<?php esc_attr_e( $options['fll_team_city'] ); ?>" />
					</td>
				</tr>
				<tr valign="top"><th scope="row"><?php _e( 'State' ); ?></th>
					<td>
						<input id="fll_theme_options[fll_team_state]" class="regular-text" type="text" name="fll_theme_options[fll_team_state]" value="<?php esc_attr_e( $options['fll_team_state'] ); ?>" />
					</td>
				</tr>
				
				<?php
				/**
				 * Sharing Links
				 */
				?>
				<tr valign="top"><th scope="row"><?php _e( 'Link to Team\'s Twitter' ); ?></th>
					<td>
						<input id="fll_theme_options[fll_team_social_twitter]" class="regular-text" type="text" name="fll_theme_options[fll_team_social_twitter]" value="<?php esc_attr_e( $options['fll_team_social_twitter'] ); ?>" />
						<label class="description" for="fll_theme_options[fll_team_social_twitter]"><?php _e( 'ex: http://twitter.com/teamname' ); ?></label>
					</td>
				</tr>
				<tr valign="top"><th scope="row"><?php _e( 'Link to Team\'s Facebook' ); ?></th>
					<td>
						<input id="fll_theme_options[fll_team_social_facebook]" class="regular-text" type="text" name="fll_theme_options[fll_team_social_facebook]" value="<?php esc_attr_e( $options['fll_team_social_facebook'] ); ?>" />
						<label class="description" for="fll_theme_options[fll_team_social_facebook]"><?php _e( 'ex: http://facebook.com/teamname' ); ?></label>
					</td>
				</tr>
				<tr valign="top"><th scope="row"><?php _e( 'Link to Team\'s Flickr' ); ?></th>
					<td>
						<input id="fll_theme_options[fll_team_social_flickr]" class="regular-text" type="text" name="fll_theme_options[fll_team_social_flickr]" value="<?php esc_attr_e( $options['fll_team_social_flickr'] ); ?>" />
						<label class="description" for="fll_theme_options[fll_team_social_flickr]"><?php _e( 'ex: http://flickr.com/photos/teamname' ); ?></label>
					</td>
				</tr>
				<tr valign="top"><th scope="row"><?php _e( 'Link to Team\'s YouTube' ); ?></th>
					<td>
						<input id="fll_theme_options[fll_team_social_youtube]" class="regular-text" type="text" name="fll_theme_options[fll_team_social_youtube]" value="<?php esc_attr_e( $options['fll_team_social_youtube'] ); ?>" />
						<label class="description" for="fll_theme_options[fll_team_social_youtube]"><?php _e( 'ex: http://youtube.com/teamname' ); ?></label>
					</td>
				</tr>

			</table>

			<p class="submit">
				<input type="submit" class="button-primary" value="<?php _e( 'Save Options' ); ?>" />
			</p>
		</form>
	</div>
	<?php
}

/**
 * Sanitize and validate input. Accepts an array, return a sanitized array.
 */
function theme_options_validate( $input ) {
	global $select_options, $radio_options;

	// Our checkbox value is either 0 or 1
	foreach (array(
		'fll_primary_elements',
		'fll_sidebar_twitter',
		'fll_sidebar_youtube'
		) as $checkbox) {
		if ( ! isset( $input[$checkbox] ) )
			$input[$checkbox] = null;
		$input[$checkbox] = ( $input[$checkbox] == 1 ? 1 : 0 );
	}

	// Text options that should be safe and free of HTML tags
	foreach (array(
		'fll_team_number',
		'fll_team_city',
		'fll_team_state',
		'fll_team_social_twitter',
		'fll_team_social_facebook',
		'fll_team_social_flickr',
		'fll_team_social_youtube'
		) as $field_name) {
		$input[$field_name] = wp_filter_nohtml_kses( $input[$field_name] );
	}

	// Our select option must actually be in our array of select options
	if ( ! array_key_exists( $input['selectinput'], $select_options ) )
		$input['selectinput'] = null;

	// Our radio option must actually be in our array of radio options
	if ( ! isset( $input['radioinput'] ) )
		$input['radioinput'] = null;
	if ( ! array_key_exists( $input['radioinput'], $radio_options ) )
		$input['radioinput'] = null;

	// Say our textarea option must be safe text with the allowed tags for posts
	$input['sometextarea'] = wp_filter_post_kses( $input['sometextarea'] );

	return $input;
}

// adapted from http://planetozh.com/blog/2009/05/handling-plugins-options-in-wordpress-28-with-register_setting/